/*****************************************************************************
  File:     InterDesk.h

    This file is Copyright (C) 1996 Scott C. Moonen.  All Rights Reserved.

  Purpose:  This header file contains constants, typedefs, defintitions, and
            declarations which user programs may use to interface with the
            InterDesk Graphical Shell, for the purpose of utilizing some of
            the advanced services it provides, such as drag-and-drop
            mediating and application auto-startup.
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

/* Include InterDesk library.                                               */

#if defined     (__386__)
#   pragma library (InterDesk3r)
#elif defined   (__SMALL__)
#   pragma library (InterDesks)
#elif defined   (__COMPACT__)
#   pragma library (InterDeskc)
#elif defined   (__MEDIUM__)
#   pragma library (InterDeskm)
#elif defined   (__LARGE__)
#   pragma library (InterDeskl)
#elif defined   (__HUGE__)
#   pragma library (InterDeskh)
#else
#   pragma library (InterDeskl)
#endif

/* QNXWin user event to redraw a window.                                    */

#define QW_REDRAW   'rd'

/* Maximum buffer size.                                                     */

#define DRAGDROP_MAXBUFSIZE   8192

/* Result values for shell operations.                                      */

#define ID_SUCCESS            0x0000    /* Successful operation.            */
#define ID_ERR_NOSHELL        0x0001    /* IDsk shell isn't running.        */
#define ID_ERR_INVREQUEST     0x0002    /* Invalid operation requested.     */
#define ID_ERR_TOOMANYWINS    0x0003    /* Too many registered windows.     */
#define ID_ERR_OUTOFMEM       0x0004    /* Out of memory.                   */
#define ID_ERR_WINNOTREG      0x0005    /* Window isn't registered!         */
#define ID_ERR_SENDMSG        0x0006    /* Error sending message.           */
#define ID_ERR_INVDRAGID      0x0007    /* Invalid drag id number.          */
#define ID_ERR_TOOMUCHDATA    0x0008    /* Too many chunks given to shell.  */
#define ID_ERR_CHUNKTOOBIG    0x0009    /* Data chunk is too big!           */
#define ID_ERR_NOTENOUGHDATA  0x000A    /* Not enough chunks of data sent!  */
#define ID_ERR_TRYAGAIN       0x000B    /* Resource unavailable, try again. */
#define ID_ERR_NOMOREDATA     0x000C    /* No more chunks of data exist.    */
#define ID_ERR_NOOPERATION    0x000D    /* No current drag operation.       */
#define ID_ERR_DRAGTOSELF     0x000E    /* Can't drag to self.              */

/* Function declarations.                                                   */

short   IDRegDragSrc(int win_id,        /* Register a win as a drag source. */
          char is_dir_win);
short   IDRegDragTarget(int win_id);    /* Register a win as a drag target. */
short   IDUnRegDragSrc(int win_id);     /* Unregister win as drag source.   */
short   IDUnRegDragTarget(int win_id);  /* Unregister win as drag target.   */
char   *IDErrMsg(short err_val);        /* Get error message for error val. */
short   IDTargetQuery(int win_id,       /* Ask if a window is a drag target.*/
          short *is_target);
short   IDSourceQuery(int win_id,       /* Ask if a window is a drag source.*/
          short *is_source);
short   IDDragStart(int src_win,        /* Initiate a drag data transfer.   */
          int target_win,short num_chunks,char *data_type,long *drag_id);
short   IDDragTransfer(long drag_id,    /* Transfer a chunk of drag data.   */
          void *data,size_t data_len);
short   IDDragEnd(long drag_id);        /* Terminate drag data transfer.    */
short   IDDropStart(int src_win,        /* Initiate a drop data transfer.   */
          int target_win,short *num_chunks,char *data_type,long *drag_id);
short   IDDropTransfer(long drag_id,    /* Transfer a chunk of drop data.   */
          void *data,size_t *data_len);
short   IDDropEnd(long drag_id,         /* Terminate a drop data transfer.  */
          short file_changed);
short   IDAutoStart(char *command);     /* Add autostartup entry.           */
